Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(59)

Unified Diff: pkg/analyzer/lib/src/generated/utilities_general.dart

Issue 1394533002: Remove final users of dart:profiler library (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/compiler/lib/src/common/tasks.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/generated/utilities_general.dart
diff --git a/pkg/analyzer/lib/src/generated/utilities_general.dart b/pkg/analyzer/lib/src/generated/utilities_general.dart
index 83bfaa1a7db664dfbeed99aae9bb84e4adbf7f11..d120a81abdd6e0a9b12554d53bbb5c556f21071f 100644
--- a/pkg/analyzer/lib/src/generated/utilities_general.dart
+++ b/pkg/analyzer/lib/src/generated/utilities_general.dart
@@ -4,7 +4,7 @@
library engine.utilities.general;
-import 'dart:profiler';
+import 'dart:developer' show UserTag;
/**
* Jenkins hash function, optimized for small integers.
@@ -33,7 +33,7 @@ class JenkinsSmiHash {
/**
* Helper class for gathering performance statistics. This class is modeled on
* the UserTag class in dart:profiler so that it can interoperate easily with
* it.
*/
abstract class PerformanceTag {
@@ -33,7 +33,7 @@ class JenkinsSmiHash {
/**
* Helper class for gathering performance statistics. This class is modeled on
- * the UserTag class in dart:profiler so that it can interoperate easily with
+ * the UserTag class in dart:developer so that it can interoperate easily with
* it.
*/
« no previous file with comments | « no previous file | pkg/compiler/lib/src/common/tasks.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698